@@ -170,6 +170,10 @@ typedef struct mpd_Status {
 	int repeat;
 	/* 1 if random is on, 0 otherwise */
 	int random;
+    /* 1 if single in on, 0 otherwise */
+    int single;
+    /* 1 if single is on, 0 otherwise */
+    int consume;
 	/* playlist length */
 	int playlistLength;
 	/* playlist, use this to determine when the playlist has changed */
@@ -187,6 +191,12 @@ typedef struct mpd_Status {
 	int song;
 	/* Song ID of the currently selected song */
 	int songid;
+
+    /* The next song pos */
+    int nextsong;
+    /* The next song id */
+    int nextsongid;
+
 	/* time in seconds that have elapsed in the currently playing/paused
 	 * song
 	 */
@@ -507,19 +517,20 @@ void mpd_sendSwapCommand(mpd_Connection * connection, int song1, int song2);
 
 void mpd_sendSwapIdCommand(mpd_Connection * connection, int song1, int song2);
 
-void mpd_sendSeekCommand(mpd_Connection * connection, int song, int time);
+void mpd_sendSeekCommand(mpd_Connection * connection, int song, int seek_time);
 
-void mpd_sendSeekIdCommand(mpd_Connection * connection, int song, int time);
+void mpd_sendSeekIdCommand(mpd_Connection * connection, int song, int seek_time);
 
 void mpd_sendRepeatCommand(mpd_Connection * connection, int repeatMode);
 
+void mpd_sendSingleCommand(mpd_Connection * connection, int singleMode);
+
+void mpd_sendConsumeCommand(mpd_Connection * connection, int consumeMode);
+
 void mpd_sendRandomCommand(mpd_Connection * connection, int randomMode);
 
 void mpd_sendSetvolCommand(mpd_Connection * connection, int volumeChange);
 
-/* WARNING: don't use volume command, its depreacted */
-void mpd_sendVolumeCommand(mpd_Connection * connection, int volumeChange);
-
 void mpd_sendCrossfadeCommand(mpd_Connection * connection, int seconds);
 
 void mpd_sendUpdateCommand(mpd_Connection * connection,const char * path);
